// Copyright 2016 Orus.io. All rights reserved.

package model

import (
	"time"

	"github.com/m4rw3r/uuid"

	"bitbucket.org/orus-io/go-xbus/api"
)

//go:generate yago --fmt

// Process stores process data
//yago:
type Process struct {
	Base
	TriggerEmitterID  uuid.UUID `yago:"fk=Actor"`
	TriggerEnvelopeID uuid.UUID `yago:"fk=Envelope"`
	GraphID           uuid.UUID `yago:"."`
	SourceNodeID      string    `yago:"."`
	SourceSlotID      string    `yago:"."`
}

// Route stores routes associated to each node output in a
// Process
//yago:
type Route struct {
	ID         int64     `yago:"primary_key,auto_increment"`
	ProcessID  uuid.UUID `yago:"fk=Process ONDELETE CASCADE,unique_index=route"`
	Source     string    `yago:"unique_index=route,type=qb.Text()"`
	EnvelopeID uuid.UUID `yago:"unique_index=route"`
}

//RouteTarget stores the targets of Route
//yago:
type RouteTarget struct {
	ID      int64     `yago:"primary_key,auto_increment"`
	RouteID int64     `yago:"fk=Route ONDELETE CASCADE,unique_index=target"`
	ActorID uuid.UUID `yago:"fk=Actor,unique_index=target"`
	NodeID  string    `yago:"unique_index=target"`
	Input   string    `yago:"unique_index=target"`
}

// ProcessLogEntry stores storage.ProcessLogEntry
//yago:
type ProcessLogEntry struct {
	ID              int64     `yago:"primary_key,auto_increment"`
	Timestamp       time.Time `yago:"."`
	ProcessID       uuid.UUID `yago:"fk=Process ONDELETE CASCADE"`
	Data            string    `yago:"type=qb.Text()"`
	LogProcessed    bool      `yago:"."`
	ProcessingError bool      `yago:"."`
}

// ProcessState stores a storage.ProcessState
//yago:autoattrs
type ProcessState struct {
	ProcessID         uuid.UUID          `yago:"primary_key,fk=Process ONDELETE CASCADE"`
	Status            api.Process_Status `yago:"textmarshaled"`
	StatusChanged     time.Time
	StatusReason      string `yago:"type=qb.Text()"`
	NodeStates        string `yago:"type=qb.Text()"`
	NodeStatesChanged time.Time
	PMLevel           api.LogLevel         `yago:"textmarshaled"`
	PMStatus          api.PMProcess_Status `yago:"textmarshaled"`
	PMComment         string
	PMChanged         time.Time
}
