package utils

import (
	"fmt"
	"strconv"
	"time"
)

// ParseDateOrDuration parses a data expressed as a iso formated date
// or a duration in days, months or years from Now()
func ParseDateOrDuration(s string) (time.Time, error) {
	if len(s) == 0 {
		return time.Time{}, fmt.Errorf("empty string")
	}
	lastchar := s[len(s)-1]
	if lastchar == 'y' || lastchar == 'm' || lastchar == 'd' {
		n, err := strconv.Atoi(s[:len(s)-1])
		if err != nil {
			return time.Time{}, err
		}
		year, month, day := time.Now().Date()
		t := time.Date(year, month, day, 0, 0, 0, 0, time.Local)
		switch lastchar {
		case 'y':
			t = t.AddDate(n, 0, 0)
		case 'm':
			t = t.AddDate(0, n, 0)
		case 'd':
			t = t.AddDate(0, 0, n)
		}
		return t, nil
	}
	return time.ParseInLocation("2006-01-02", s, time.Local)
}
