// Copyright 2016 Orus.io. All rights reserved.

package api

const (
	// Msgbox is were envelopes are sent
	Msgbox = XbusAPIPrefix + "msgbox"

	// DefaultInput is the name of the default input
	DefaultInput = "default"
	// DefaultOutput is the name of the default output
	DefaultOutput = "default"
)

// EmitterMsgboxSubject returns the msgbox for an emitter
func EmitterMsgboxSubject(id UUID) string {
	return Msgbox + "." + id.String()
}

// ActorOutputSubject returns the subject for an actor output
func ActorOutputSubject(id UUID) string {
	return XbusAPIPrefix + "broker." + id.String() + ".output"
}

// ActorInputSubject returns the subject for an actor input
func ActorInputSubject(id UUID, output string) string {
	return Msgbox + "." + id.String() + ".input." + output
}

var (
	// EnvelopeMaxSize is an approximate maximum size of an envelope
	// A single Envelope should never exceed this size, or it could be
	// rejected by nats
	EnvelopeMaxSize = 750 * 1024 // 750K encrypted should be smaller than 1M
)

// NewEnvelopeAck creates a normal EnvelopeAck
func NewEnvelopeAck(id UUID, status EnvelopeAck_ReceptionStatus) *EnvelopeAck {
	return &EnvelopeAck{
		ID:     id,
		Status: status,
	}
}

// NewEnvelopeAckError prepare a EnvelopeAck from an error
func NewEnvelopeAckError(id UUID, err error) *EnvelopeAck {
	return &EnvelopeAck{
		ID:     id,
		Status: EnvelopeAck_ERROR,
		Reason: err.Error(),
	}
}
